import { __decorate } from "tslib";
import { bodyFont } from '@microsoft/fast-components';
import { customElement, FASTElement, observable, attr, DOM } from '@microsoft/fast-element';
import { defaultBodyFont, EventName } from '../../types';
import { applyStyleChanges } from '../../utils/utils';
import { JSON_SCHEMA, JSON_SCHEMA_ARRAY, uiSchema, uiSchemaArray } from './json_schema';
import { PreviewFormStyles as styles } from './preview-form.styles';
import { PreviewFormTemplate as template } from './preview-form.template';
let PreviewForm = class PreviewForm extends FASTElement {
    constructor() {
        super(...arguments);
        this.jsonSchema = JSON_SCHEMA;
        this.uischema = uiSchema;
        this.jsonSchemaArray = JSON_SCHEMA_ARRAY;
        this.uiSchemaArray = uiSchemaArray;
        this.prefix = 'zero';
        this.editedEntity = {
            group1: {
                NAME: 'Test Name',
            },
            group2: {
                COUNTERPARTY_ID: 'GENESIS',
                INSTRUMENT_ID: 'BOND',
            },
        };
        this.editedEntityArray = {
            users: [
                {
                    firstname: 'Max',
                    lastname: 'Mustermann',
                    age: 25,
                    email: 'max@mustermann.com',
                },
                {
                    firstname: 'John',
                    lastname: 'Doe',
                    age: 35,
                    email: 'john@doe.com',
                },
            ],
        };
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                applyStyleChanges(detail, this.provider);
            });
        }
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        this.uischema.dsPrefix = event.detail.prefix;
        this.uiSchemaArray.dsPrefix = event.detail.prefix;
    }
};
__decorate([
    observable
], PreviewForm.prototype, "jsonSchema", void 0);
__decorate([
    observable
], PreviewForm.prototype, "uischema", void 0);
__decorate([
    observable
], PreviewForm.prototype, "jsonSchemaArray", void 0);
__decorate([
    observable
], PreviewForm.prototype, "uiSchemaArray", void 0);
__decorate([
    attr
], PreviewForm.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewForm.prototype, "provider", void 0);
__decorate([
    observable
], PreviewForm.prototype, "editedEntity", void 0);
__decorate([
    observable
], PreviewForm.prototype, "editedEntityArray", void 0);
PreviewForm = __decorate([
    customElement({
        name: 'preview-form',
        template,
        styles,
    })
], PreviewForm);
export { PreviewForm };
